@@ -187,7 +187,7 @@ class BillPayments(Resource):
                     "ownerInvoiceNumber": payload.get("invoice_id", ""),
                     "ownerNumber": payload.get("vendor_id", ""),
                     "description": payload.get("description", ""),
-                    "amount": payload.get("amount", ""),
+                    "amount": payload.get("amount", 0),
                     "bankCode": payload.get("bank_code", ""),
                 })
 
