@@ -159,6 +159,21 @@ class ChartOfAccounts(Resource):
 
                     additional_properties.pop("Status")
 
+            # If client type is ODOO
+            elif super().get_client_type() == super().ODOO:
+                if 'account_name' in payload.keys():
+                    data.update({
+                        "name": payload.get("account_name", "")
+                    })
+                if 'account_code' in payload.keys():
+                    data.update({
+                        "code": payload.get("account_code", "")
+                    })
+                if 'account_type' in payload.keys():
+                    data.update({
+                        "user_type_id": int(payload.get("account_type", 0))
+                    })
+
             data.update(additional_properties)
 
             return data
